@@ -12,7 +12,7 @@ from typing import (
 
 from datetime import datetime
 
-from google.cloud.exceptions import Conflict
+from google.cloud.exceptions import Conflict, NotFound
 from google.cloud.firestore_v1.base_query import BaseQuery
 from google.cloud.firestore_v1.transforms import Sentinel, ArrayUnion, ArrayRemove
 from google.cloud.firestore_v1.field_path import (
@@ -46,9 +46,7 @@ OwnerDataContainer = dict[str, Any]
 class OwnerDataContainer(TypedDict, total=True):
     state: Union[_free_marker_literal, _owned_marker_literal, _retired_marker_literal]
     data: dict[str, Any]
-    modified: Union[
-        Sentinel, Any
-    ]  # actually SERVER_TIMESTAMP — what is that when it comes back?
+    modified: Union[Sentinel, datetime]
 
 
 class OwnedDataContainer(OwnerDataContainer):
@@ -87,6 +85,9 @@ class SetValue:
     def _update(self, data: dict[str, Any]) -> None:
         data[self._key] = self._value
 
+    def __repr__(self):
+        return f"SetValue({self._key}, {self._value}"
+
 
 class AddToList:
     def __init__(self, key: str, *values: Any):
@@ -96,8 +97,10 @@ class AddToList:
     def _update(self, data: dict[str, Any]) -> None:
         data[self._key] = ArrayUnion(self._values)
 
+    def __repr__(self):
+        return f"AddToList({self._key}, {', '.join(self._values)}"
 
-class RetirableResources:
+class RetirableResourceManager:
     def __init__(
         self, root_doc_path: Union[str, tuple[str], list[str]], *, client: Client
     ):
@@ -173,7 +176,6 @@ class RetirableResources:
 
         return t_take(self._client.transaction())
 
-
     def status(self, resource: str, owner: str) -> Literal["owned", "free", "retired"]:
         """Return the status of the resource as owned by `owner`
 
@@ -283,15 +285,20 @@ class RetirableResources:
         for command in update_commands:
             command._update(updates)
 
-        self._resource_docref(resource).update(
-            {
-                **{
-                    FieldPath(owner, "data", key).to_api_repr(): value
-                    for key, value in updates.items()
-                },
-                FieldPath(owner, "modified").to_api_repr(): SERVER_TIMESTAMP,
-            }
-        )
+        docref = self._resource_docref(resource)
+
+        try:
+            docref.update(
+                {
+                    **{
+                        FieldPath(owner, "data", key).to_api_repr(): value
+                        for key, value in updates.items()
+                    },
+                    FieldPath(owner, "modified").to_api_repr(): SERVER_TIMESTAMP,
+                }
+            )
+        except NotFound:
+            raise ResourceDoesNotExist(resource)
 
     def list_allocation(self, owner: str, tag: str) -> set[str]:
         """Returns set of resources allocated to the owner and tag"""
@@ -333,27 +340,26 @@ class RetirableResources:
         for resource in self._resources_by_state(owner, _owned_marker):
             self.free(resource, owner)
 
-
-    def free_allocation_count(self, owner:str) -> int:
+    def free_allocation_count(self, owner: str) -> int:
         """How many resources are available to become allocated for owner
-        
+
         Caution: Because Firestore has no `count` operation, this operation may
         be unexpectedly expensive.
         """
         return len(self._resources_by_state(owner, _free_marker))
 
-    def when_modified(self, resource:str, owner:str) -> datetime:
+    def when_modified(self, resource: str, owner: str) -> datetime:
         owner_dict = self._owner_data_container(resource, owner)
-        return owner_dict['modified']
+        return owner_dict["modified"]
 
     @staticmethod
-    def _doc_owner_dict(doc:DocumentSnapshot, owner:str) -> datetime:
+    def _doc_owner_dict(doc: DocumentSnapshot, owner: str) -> datetime:
         owner_dict = doc.to_dict().get(owner)
         if owner_dict is None:
-            raise Exception('invalid owner_dict for doc', doc.id)
+            raise Exception("invalid owner_dict for doc", doc.id)
         return owner_dict
 
-    def _owner_data_container(self, resource:str, owner:str) -> OwnerDataContainer:
+    def _owner_data_container(self, resource: str, owner: str) -> OwnerDataContainer:
         owners_dict = self._resource_owners_dict(resource)
         if owners_dict is None:
             raise ResourceDoesNotExist(resource)
@@ -362,7 +368,7 @@ class RetirableResources:
             raise OwnerDoesNotExist(resource, owner)
         return owner_dict
 
-    def _resources_by_state(self, owner:str, state:str) -> set[str]:
+    def _resources_by_state(self, owner: str, state: str) -> set[str]:
         docs = (
             self._resources_collection()
             .where(
@@ -532,27 +538,3 @@ class RetirableResources:
             "data": {},
             "modified": SERVER_TIMESTAMP,
         }
-
-
-class OwnerView:
-    def __init__(self, owner: str, retirable_resources: RetirableResources):
-        self._owner = owner
-        self._r = retirable_resources
-
-    def take(self, tag: str) -> Optional[str]:
-        return self._r.take(self._owner, tag=tag)
-
-    def status(self, resource: str) -> Literal["owned", "free", "retired"]:
-        return self._r.status(resource, owner=self._owner)
-
-    def retire(self, resource: str) -> Literal["resource retired", "resource active"]:
-        return self._r.retire(resource, owner=self._owner)
-
-    def free(self, resource: str) -> None:
-        self._r.free(resource, owner=self._owner)
-
-    def get_data(self, resource: str) -> dict:
-        return self._r.get_data(resource, owner=self._owner)
-
-    def update_data(self, resource: str, *update_commands: UpdateCommand) -> None:
-        self._r.update_data(resource, self._owner, *update_commands)
